@@ -1,7 +1,7 @@
 package Perinci::Examples::CLI;
 
-our $DATE = '2015-11-28'; # DATE
-our $VERSION = '0.63'; # VERSION
+our $DATE = '2016-01-19'; # DATE
+our $VERSION = '0.64'; # VERSION
 
 use 5.010001;
 use strict;
@@ -323,40 +323,7 @@ Perinci::Examples::CLI - Example for CLI help/usage generation
 
 =head1 VERSION
 
-This document describes version 0.63 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2015-11-28.
-
-=head1 SEE ALSO
-
-L<Perinci>
-
-L<Perinci::Examples>
-
-=head1 HOMEPAGE
-
-Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Examples>.
-
-=head1 SOURCE
-
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Examples>.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Examples>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2015 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This document describes version 0.64 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2016-01-19.
 
 =head1 DESCRIPTION
 
@@ -375,8 +342,11 @@ Summary for `demo_cli_opts`.
 
 Examples:
 
- demo_cli_opts( array1 => ["elem1", "elem2"], int1 => 10, str1 => "a value");
+=over
 
+=item * Summary for an example:
+
+ demo_cli_opts( str1 => "a value", array1 => ["elem1", "elem2"], int1 => 10);
 
 Result:
 
@@ -392,12 +362,12 @@ Result:
      int2   => 10,
      str1   => "a value",
    },
+   {},
  ]
-Summary for an example.
 
+=item * A second example:
 
- demo_cli_opts( array1 => [1, 2], int1 => 20, str1 => "x");
-
+ demo_cli_opts( str1 => "x", array1 => [1, 2], int1 => 20);
 
 Result:
 
@@ -410,17 +380,17 @@ Result:
                {
                  file    => "/home/s1/perl5/perlbrew/perls/perl-5.22.0/lib/site_perl/5.22.0/Perinci/Access/Schemeless.pm",
                  func    => "Perinci::Access::Schemeless::action_call",
-                 line    => 477,
+                 line    => 494,
                  package => "Perinci::Access::Schemeless",
-                 time    => 1448705124,
+                 time    => 1453211668,
                  type    => "create",
                },
              ],
      prev => [500, "GetOptions failed"],
    },
  ]
-A second example.
 
+=back
 
 Description for C<demo_cli_opts>.
 
@@ -566,11 +536,17 @@ Function summary.
 
 Examples:
 
- demo_cli_opts_shorter( bool1 => 1, str1 => "a value"); # -> [200, "OK", { bool1 => 1, str1 => "a value" }]
+=over
 
+=item * Summary for an example:
 
-Summary for an example.
+ demo_cli_opts_shorter( str1 => "a value", bool1 => 1);
 
+Result:
+
+ [200, "OK", { bool1 => 1, str1 => "a value" }, {}]
+
+=back
 
 This function is not exportable.
 
@@ -601,4 +577,37 @@ that contains extra information.
 
 Return value:  (any)
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Examples>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Examples>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 SEE ALSO
+
+L<Perinci>
+
+L<Perinci::Examples>
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2016 by perlancar@cpan.org.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
